==> fdo-3.2.2.tar.gz: OpenSource_FDO/Fdo/Managed/Src/OSGeo/FDO/Commands/Locking/mgILockConflictReaderImp.cpp <==
/*
* 
* Copyright (C) 2004-2006  Autodesk, Inc.
* 
* This library is free software; you can redistribute it and/or
* modify it under the terms of version 2.1 of the GNU Lesser
* General Public License as published by the Free Software Foundation.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*
*/

#include "stdafx.h"
#include <Fdo\Commands\Locking\ILockConflictReader.h>
#include <Fdo\Commands\CommandType.h>

#include "FDO\Commands\Locking\mgILockConflictReaderImp.h"
#include "FDO\mgObjectFactory.h"
#include "FDO\Commands\mgPropertyValueCollection.h"

System::Void NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::ReleaseUnmanagedObject()
{
	if (get_AutoDelete()) 
        EXCEPTION_HANDLER(GetImpObj()->Release())
	Detach();
}

FdoILockConflictReader* NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetImpObj()
{
    return static_cast<FdoILockConflictReader*>(__super::UnmanagedObject.ToPointer());
}

System::String* NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetFeatureClassName()
{
	FdoString* result;

	EXCEPTION_HANDLER(result = GetImpObj()->GetFeatureClassName())

	return result;
}

NAMESPACE_OSGEO_FDO_COMMANDS::PropertyValueCollection* NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetIdentity()
{
	FdoPropertyValueCollection* result;

	EXCEPTION_HANDLER(result = GetImpObj()->GetIdentity())

    return NAMESPACE_OSGEO_FDO::ObjectFactory::CreatePropertyValueCollection(result, true);
}

System::String* NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetLockOwner()
{
	FdoString* result;

	EXCEPTION_HANDLER(result = GetImpObj()->GetLockOwner())

	return result;
}

System::String* NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetLongTransaction()
{
	FdoString* result;

	EXCEPTION_HANDLER(result = GetImpObj()->GetLongTransaction())

	return result;
}

NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ConflictType NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetConflictType()
{
	FdoConflictType result;

	EXCEPTION_HANDLER(result = GetImpObj()->GetConflictType())

	return static_cast<NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ConflictType>(result);
}

System::Boolean NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::ReadNext()
{
	FdoBoolean result;

	EXCEPTION_HANDLER(result = !!GetImpObj()->ReadNext())

	return result;
}

System::Void NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::Close()
{
	EXCEPTION_HANDLER(GetImpObj()->Close())
}

==> fdo-3.5.0_5667.tar.gz: OpenSource_FDO/Fdo/Managed/Src/OSGeo/FDO/Commands/Locking/mgILockConflictReaderImp.cpp <==
/*
* 
* Copyright (C) 2004-2006  Autodesk, Inc.
* 
* This library is free software; you can redistribute it and/or
* modify it under the terms of version 2.1 of the GNU Lesser
* General Public License as published by the Free Software Foundation.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*
*/

#include "stdafx.h"
#include <Fdo\Commands\Locking\ILockConflictReader.h>
#include <Fdo\Commands\CommandType.h>

#include "FDO\Commands\Locking\mgILockConflictReaderImp.h"
#include "FDO\mgObjectFactory.h"
#include "FDO\Commands\mgPropertyValueCollection.h"

FdoILockConflictReader* NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetImpObj()
{
    return static_cast<FdoILockConflictReader*>(UnmanagedObject.ToPointer());
}

IntPtr NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetDisposableObject()
{
    return IntPtr(static_cast<FdoIDisposable*>(GetImpObj()));
}

System::String^ NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetFeatureClassName()
{
	FdoString* result;

	EXCEPTION_HANDLER(result = GetImpObj()->GetFeatureClassName())

	return CHECK_STRING(result);
}

NAMESPACE_OSGEO_FDO_COMMANDS::PropertyValueCollection^ NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetIdentity()
{
	FdoPropertyValueCollection* result;

	EXCEPTION_HANDLER(result = GetImpObj()->GetIdentity())

    return NAMESPACE_OSGEO_FDO::ObjectFactory::CreatePropertyValueCollection(IntPtr(result), true);
}

System::String^ NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetLockOwner()
{
	FdoString* result;

	EXCEPTION_HANDLER(result = GetImpObj()->GetLockOwner())

	return CHECK_STRING(result);
}

System::String^ NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetLongTransaction()
{
	FdoString* result;

	EXCEPTION_HANDLER(result = GetImpObj()->GetLongTransaction())

	return CHECK_STRING(result);
}

NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ConflictType NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::GetConflictType()
{
	FdoConflictType result;

	EXCEPTION_HANDLER(result = GetImpObj()->GetConflictType())

	return static_cast<NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ConflictType>(result);
}

System::Boolean NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::ReadNext()
{
	System::Boolean result;

	EXCEPTION_HANDLER(result = !!GetImpObj()->ReadNext())

	return result;
}

System::Void NAMESPACE_OSGEO_FDO_COMMANDS_LOCKING::ILockConflictReaderImp::Close()
{
	EXCEPTION_HANDLER(GetImpObj()->Close())
}
